<!--新增修改页面-->
<template>
  <div class="bbsl-common-page">
    <div class="title-box">
      <el-page-header @back="closePage" :content="title" />
    </div>
    <div class="bbsl-table-search">
      <el-form v-model="queryParams" :inline="true" label-suffix="：">
        <el-form-item label="设备名称">
          <el-input
            :clearable="true"
            placeholder="请输入设备名称"
            v-model="queryParams.inspectionPlanName"
          />
        </el-form-item>
        <el-form-item label="是否巡检">
          <el-select
            placeholder="请选择是否巡检"
            v-model="queryParams.inspectionStatus"
            clearable
          >
            <el-option
              v-for="item in sfxjOpt"
              :key="item.value"
              :label="item.name"
              :value="item.value"
            />
          </el-select>
        </el-form-item>
        <el-form-item label="产品" prop="productId">
          <el-cascader
            filterable
            v-model="queryParams.productId"
            :options="productData"
            :show-all-levels="false"
            ref="cascaderRef"
            :props="{
                label: 'name',
                value: 'id',
                children: 'children',
                emitPath:false,
                checkStrictly:true
            }"
            style="width: 100%;"
            clearable
            placeholder="请选择产品"
          >
          </el-cascader>
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" @click="handleSearch">
            搜索
          </el-button>
          <el-button icon="el-icon-refresh" @click="handleReset">
            重置
          </el-button>
        </el-form-item>
      </el-form>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel">
      </div>
      <el-table
        border
        size="mini"
        v-loading="loading"
        ref="multipleSelection"
        :data="tableData"
        :style="{width: '100%'}"
        :max-height="tableMaxHeight"
        :cell-style="{'text-align': 'center'}"
        :header-cell-style="{'text-align': 'center'}"
        @selection-change="handleSelectionChange"
        row-key="id"
      >
        <el-table-column type="index" width="70" label="序号" align="center" />
        <el-table-column
          prop="name"
          show-overflow-tooltip
          align="center"
          label="设备名称"
          min-width="200"
        />
        <el-table-column
          prop="areaName"
          show-overflow-tooltip
          align="center"
          label="所属区域"
          min-width="150"
        />
        <el-table-column
          prop="productName"
          show-overflow-tooltip
          align="center"
          label="产品"
          min-width="150"
        />
        <el-table-column
          prop="inspectionStatus"
          show-overflow-tooltip
          align="center"
          label="是否巡检"
          min-width="100"
          :formatter="({inspectionStatus}) => dictionaryEscape(sfxjOpt,inspectionStatus)"
        />
        <el-table-column
          prop="inspectionTime"
          show-overflow-tooltip
          align="center"
          label="维修时间"
          min-width="120"
        />
        <el-table-column
          prop="description"
          show-overflow-tooltip
          align="center"
          label="故障描述"
          min-width="200"
        />
        <el-table-column show-overflow-tooltip min-width="150" align="center" fixed="right" label="操作">
          <template v-slot="{ row }">
            <el-link
              type="primary"
              :underline="false"
              style="margin-right: 15px;"
              @click="showDialog('patrolDialog',row)">
              巡查设备
            </el-link>
            <el-link
              :disabled=" row.inspectionStatus === '0' || !row.inspectionDeviceStatus || row.inspectionDeviceStatus === '1' || row.maintenanceStatus === '1'"
              type="warning"
              :underline="false" style="margin-right: 15px;" @click="faultWorkOrderFunc(row)"
            >
              报事报修
            </el-link>
          </template>
        </el-table-column>
      </el-table>
      <el-pagination
        align="right"
        background
        class="bbsl-pagination"
        ref="paginationPanel"
        @size-change="handleSizeChange"
        @current-change="handleCurrentChange"
        :current-page="queryParams.pageNum"
        :page-sizes="[20, 30, 40, 50]"
        :page-size="queryParams.pageSize"
        layout="total, sizes, prev, pager, next, jumper"
        :total="queryParams.total"
      ></el-pagination>
    </div>

    <!-- 巡查设备弹层 -->
    <PatrolDialog
      :patrolDialog.sync="patrolDialog"
      :row="row"
      @closeDialog="closeDialog"
    />
  </div>
</template>

<script>
import {
  equipmentTable,
  getProductTree,
  faultWorkOrder
} from '@/api/device/resourceInspection/inspectionEquipment'
import {TableMixin} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils'
import {dictionaryEscape} from '@/utils/dictionary'
import PatrolDialog from './components/PatrolDialog.vue'

export default {
  name: 'DeviceListPage',
  mixins: [TableMixin],
  components: {PatrolDialog},
  props: {
    rowInfo: {
      default: _ => ({}),
      type: Object
    }
  },
  computed: {},
  data() {
    return {
      title: '标题',
      queryParams: {
        areaName: '',
        inspectionContent: '',
        inspectionDeviceStatus: '',
        inspectionPlanName: '',
        inspectionPlanTime: '',
        inspectionStatus: '',
        inspectionType: '',
        name: '',
        pageNum: 1,
        pageSize: 10,
        productId: ''
      },
      productData: [], // 产品列表
      sfxjOpt: dictUtils.getDictItemsFromCache('sfxj') || [], // 是否巡检
      xjztOpt: dictUtils.getDictItemsFromCache('xjzt') || [], // 巡检设备状态
      xjlxOpt: dictUtils.getDictItemsFromCache('xjlx') || [], // 巡检类型
      row: {},
      patrolDialog: false  // 是否显示巡检巡查弹层
    }
  },
  created() {
    this.openPage()
    this.loadProduct()
  },
  methods: {
    dictionaryEscape,

    // 弹层打开
    openPage() {
      const {id, inspectionPlanName} = this.rowInfo
      if (id) {
        this.title = `${inspectionPlanName} - 设备列表`
      }
    },

    // 获取list
    async loadData() {
      this.loading = true
      const {rows, total} = await equipmentTable({
        ...this.queryParams,
        id: this.rowInfo.id
      })
      this.tableData = rows
      this.queryParams.total = total
      this.loading = false
    },

    // 顶部搜索
    handleSearch() {
      this.loadData()
    },

    // 重置
    handleReset() {
      this.queryParams = this.$options.data().queryParams
      this.loadData()
    },

    // 获取产品树形列表
    async loadProduct() {
      this.productData = (await getProductTree())?.value || []
    },

    // 报事报修
    faultWorkOrderFunc(row) {
      this.$confirm('确定报事报修该设备吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(async () => {
        const loading = this.$loading({
          lock: true,
          text: `正在报事报修中，请勿操作系统...`,
          spinner: 'el-icon-loading',
          background: 'rgba(255, 255, 255, 0.9)'
        })
        if (!row.id) return
        const {state} = await faultWorkOrder(row.id)
        if (state) {
          await this.loadData()
          this.$message.success('报事报修成功')
        } else {
          this.$message.error('报事报修失败')
        }
        loading.close()
      }).catch(_ => _)
    },

    // 删除
    handleDelete(row) {
      this.$confirm('确定删除选中的巡检计划吗？', '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
      }).then(async () => {
        const loading = this.$loading({
          lock: true,
          text: `正在删除巡检计划中，请勿操作系统...`,
          spinner: 'el-icon-loading',
          background: 'rgba(255, 255, 255, 0.9)'
        })
        let ids = (row ? row.id : this.multipleSelection.join()) || ''
        if (!ids) return
        const {state, message} = await removePlan(ids)
        if (state) {
          this.queryParams.pageNum = 1
          await this.loadData()
          this.$message.success(message)
        } else {
          this.$message.error(message)
        }
        loading.close()
      }).catch(_ => _)
    },

    // 弹层关闭
    closePage() {
      this.$emit('closePage', 'deviceListPage')
      this.queryParams = this.$options.data().queryParams
    },

    // 打开弹层
    showDialog(dialog, row = {}) {
      this.row = row // 保存点击行信息
      this[dialog] = true
    },

    // 关闭弹层
    closeDialog(event) {
      switch (event) {
        case 'patrol':
          this.loadData()
          break
      }
      this.row = {}
    }
  }
}
</script>
<style lang="scss" scoped>
.bbsl-common-page {
  display: flex;
  flex-direction: column;
  height: 100%;
  row-gap: 10px;

  .title-box {
    background-color: #fff;
    height: 60px;
    display: flex;
    align-items: center;
    box-shadow: 0 0 4px 0 rgba(0, 0, 0, 0.1);
    padding: 0 20px;
    flex-shrink: 1;
  }

  .bbsl-table-search {
    flex-shrink: 1;
  }

  .bbsl-table-content {
    flex: 1;
    margin-top: 0;
  }

}

</style>
